/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg.commands;

import java.io.IOException;

import com.aragost.javahg.Changeset;
import com.aragost.javahg.Repository;
import com.aragost.javahg.commands.flags.CommitCommandFlags;

/**
 * Command class for executing <tt>hg commit</tt>. Set flags from
 * {@link CommitCommandFlags} and call the {@link #execute} method.
 */
public class CommitCommand extends CommitCommandFlags {

    private String message;

    /**
     * @param repository
     *            the repository associated with this command.
     */
    public CommitCommand(Repository repository) {
        super(repository);
        withDebugFlag();
    }

    /**
     * Check if the commit was successful. In contrast with Mercurial,
     * this returns true if <tt>hg commit</tt> exited with a return
     * code of 1. This happens if there were no changes and is
     * signaled to the caller by returning null instead of a
     * changeset.
     */
    @Override
    public boolean isSuccessful() {
        return super.isSuccessful() || getReturnCode() == 1;
    }

    /**
     * 
     * @param files
     *            the files to commit.
     * @return the changeset created by the commit, or null if nothing
     *         was committed.
     * @throws IOException
     */
    public Changeset execute(String... files) throws IOException {
        if (this.message == null) {
            throw new IllegalStateException("message not set for command");
        }
        String output = launchString(files);
        int rc = getReturnCode();
        if (rc == 1) {
            return null;
        } else {
            int length = output.length();
            String node = new String(output.substring(length - 41, length - 1));
            return getRepository().changeset(node);
        }
    }

    /**
     * Set the commit message. A message is mandatory for commit.
     */
    @Override
    public CommitCommand message(String text) {
        this.message = text;
        return super.message(text);
    }
}
