/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg.commands;

import java.util.Iterator;
import java.util.Map;

import com.aragost.javahg.Changeset;
import com.aragost.javahg.Repository;
import com.aragost.javahg.commands.flags.TagsCommandFlags;
import com.google.common.collect.Maps;

/**
 * Command class for executing <tt>hg tags</tt>. Set flags from
 * {@link TagsCommandFlags} and see the {@link #execute()} method for
 * how to run the command.
 */
public class TagsCommand extends TagsCommandFlags {

    public TagsCommand(Repository repository) {
        super(repository);
        withDebugFlag();
    }

    /**
     * Return a map mapping tag names to changeset with the tag.
     * <p>
     * The command 'hg tags' returns the pseudo tag 'tip', this is not
     * returned here.
     * 
     * @return map mapping tag name to changeset
     */
    public Map<String, Changeset> execute() {
        Map<String, Changeset> result = Maps.newHashMap();
        for (Iterator<String> iter = launchIterator(); iter.hasNext();) {
            String line = iter.next();
            int n = line.lastIndexOf(' ');
            String tag = new String(line.substring(0, n).trim());
            if (!tag.equals("tip")) {
                String node = new String(line.substring(line.indexOf(':', n) + 1));
                result.put(tag, getRepository().changeset(node));
            }
        }
        return result;
    }

}
