/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */

/*
 * Automatically generated based on Mercurial 2.1.
 */
package com.aragost.javahg.commands.flags;

import com.aragost.javahg.Repository;
import com.aragost.javahg.commands.AbstractCommand;
import com.aragost.javahg.commands.DiffCommand;

public abstract class DiffCommandFlags extends AbstractCommand {

    protected DiffCommandFlags(Repository repository) {
        super(repository);
    }

    @Override
    public final String getCommandName() {
        return "diff";
    }

    public static DiffCommand on(Repository repository) {
        return new DiffCommand(repository);
    }

    /**
     * Set the <tt>--rev</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand rev(String... revs) {
        cmdAppend("--rev", revs);
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--change</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand change(String rev) {
        cmdAppend("--change", rev);
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--text</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand text() {
        cmdAppend("--text");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--nodates</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand nodates() {
        cmdAppend("--nodates");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--show-function</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand showFunction() {
        cmdAppend("--show-function");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--reverse</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand reverse() {
        cmdAppend("--reverse");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--ignore-all-space</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand ignoreAllSpace() {
        cmdAppend("--ignore-all-space");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--ignore-space-change</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand ignoreSpaceChange() {
        cmdAppend("--ignore-space-change");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--ignore-blank-lines</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand ignoreBlankLines() {
        cmdAppend("--ignore-blank-lines");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--unified</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand unified(int num) {
        cmdAppend("--unified", num);
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--stat</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand stat() {
        cmdAppend("--stat");
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--include</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand include(String... patterns) {
        cmdAppend("--include", patterns);
        return (DiffCommand) this;
    }

    /**
     * Set the <tt>--exclude</tt> command line flag.
     * 
     * @see <a
     *      href="http://www.selenic.com/mercurial/hg.1.html#diff">Mercurial
     *      documentation</a>
     * @return this instance
     */
    public DiffCommand exclude(String... patterns) {
        cmdAppend("--exclude", patterns);
        return (DiffCommand) this;
    }

}
