/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg.internals;

import java.io.IOException;
import java.nio.charset.MalformedInputException;


public abstract class BaseStatusLine<T extends Enum<?>> {

    private T type;

    private String fileName;

    public T getType() {
        return type;
    }

    public String getFileName() {
        return fileName;
    }

    protected abstract T typeForChar(char ch);

    /**
     * Read and decode a line from an input stream. Empty the stream
     * if a {@link MalformedInputException} occurs.
     * 
     * @param stream
     *            the input stream
     * @throws IOException
     *             passed through from the underlying stream
     */
    protected void initFromStream(HgInputStream stream) throws IOException {
        char ch = (char) stream.read();
        stream.match(' ');
        try {
            this.fileName = stream.textUpTo('\n');
        } catch (MalformedInputException e) {
            stream.consumeAll();
            throw e;
        }
        this.type = typeForChar(ch);
    }

    public String toString() {
        return (this.type != null ? this.type : "-") + " " + this.fileName;
    }

}
