package com.aragost.javahg.internals;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.Map;

import com.aragost.javahg.Repository;
import com.aragost.javahg.commands.LogCommand;
import com.google.common.collect.Maps;

/**
 * Log command for reading extra dictionary one changeset
 * <p>
 * Note that this could be called with more than one revision, in
 * which case it will return a map with all extra values for all
 * revisions.
 */
public class ExtraLogCommand extends LogCommand {

    public ExtraLogCommand(Repository repository) {
        super(repository, null);
    }

    public Map<String, byte[]> execute() {
        Map<String, byte[]> result = Maps.newHashMap();
        HgInputStream stream = launchStream();
        try {
            while (stream.find("extra:".getBytes())) {
                String key = stream.textUpTo('=').trim();
                byte[] value = unescapePythonString(stream.upTo('\n'));
                result.put(key, value);
            }
        } catch (IOException e) {
            throw new RuntimeIOException(e);
        }
        return result;
    }

    private byte[] unescapePythonString(byte[] bytes) {
        ByteArrayOutputStream bos = new ByteArrayOutputStream(bytes.length);
        int index = 0;
        while (index < bytes.length) {
            byte ch = bytes[index++];
            if (ch == '\\') {
                byte ch2 = bytes[index++];
                switch (ch2) {
                case '\\':
                    ch = '\\';
                    break;
                case 'n':
                    ch = '\n';
                    break;
                case 'r':
                    ch = '\r';
                    break;
                case 't':
                    ch = '\t';
                    break;
                case 'x':
                    byte h1 = bytes[index++];
                    byte h2 = bytes[index++];
                    ch = (byte) (16 * hex(h1) + hex(h2));
                    break;
                default:
                    throw new IllegalArgumentException("Unepected character in input");
                }

            }
            bos.write(ch);
        }
        return bos.toByteArray();
    }

    private int hex(byte hexDigit) {
        if (hexDigit >= '0' && hexDigit <= '9') {
            return hexDigit - '0';
        } else if (hexDigit >= 'a' && hexDigit <= 'f') {
            return 10 + hexDigit - 'a';
        } else if (hexDigit >= 'A' && hexDigit <= 'F') {
            return 10 + hexDigit - 'A';
        } else {
            throw new IllegalArgumentException("'" + hexDigit + "' is not a hex digit");
        }
    }

}
