package com.aragost.javahg.internals;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.aragost.javahg.MercurialExtension;
import com.google.common.io.ByteStreams;

public class JavaHgMercurialExtension extends MercurialExtension {
    
    private final static Logger LOG = LoggerFactory.getLogger(JavaHgMercurialExtension.class);

    private File pythonFile;

    @Override
    public String getName() {
        return "javahg";
    }
    
    @Override
    public String getPath() {
        return this.pythonFile.getAbsolutePath();
    }

    @Override
    public void initialize() throws Exception {
        if (this.pythonFile == null || !this.pythonFile.exists()) {
            this.pythonFile = File.createTempFile("javahg", "ext");
            FileOutputStream out = new FileOutputStream(this.pythonFile);
            InputStream stream = getClass().getResourceAsStream("/javahg.py");
            ByteStreams.copy(stream, out);
            out.close();
            LOG.info("Created javahg extension file: {}", getPath());

            Runtime.getRuntime().addShutdownHook(new Thread() {
                @Override
                public void run() {
                    File f = JavaHgMercurialExtension.this.pythonFile;
                    if (f != null) {
                        f.delete();
                        LOG.info("Delete javahg extension file: {}", f.getAbsolutePath());
                    }
                }
            });
        }
    }

}
